@@ -13,6 +13,17 @@
 #include <string.h>
 #include <microhttpd.h>
 
+#ifdef _MSC_VER
+#ifndef strcasecmp
+#define strcasecmp(a,b) _stricmp((a),(b))
+#endif /* !strcasecmp */
+#endif /* _MSC_VER */
+
+#if defined(_MSC_VER) && _MSC_VER+0 <= 1800
+/* Substitution is OK while return value is not used */
+#define snprintf _snprintf
+#endif
+
 #define PORT            8888
 #define POSTBUFFERSIZE  512
 #define MAXCLIENTS      2
@@ -54,6 +65,8 @@ const char *servererrorpage =
   "<html><body>An internal server error has occured.</body></html>";
 const char *fileexistspage =
   "<html><body>This file already exists.</body></html>";
+const char* const postprocerror =
+  "<html><head><title>Error</title></head><body>Error processing POST data</body></html>";
 
 
 static int
@@ -230,9 +243,14 @@ answer_to_connection (void *cls,
 
       if (0 != *upload_data_size)
         {
-          MHD_post_process (con_info->postprocessor,
-                            upload_data,
-                            *upload_data_size);
+          if (MHD_post_process (con_info->postprocessor,
+                                upload_data,
+                                *upload_data_size) != MHD_YES)
+            {
+              return send_page (connection,
+                                postprocerror,
+                                MHD_HTTP_BAD_REQUEST);
+            }
           *upload_data_size = 0;
 
           return MHD_YES;
