@@ -180,7 +180,7 @@ main (int argc, char *const *argv)
   response = MHD_create_response_from_buffer (strlen (PAGE),
 					      (void *) PAGE,
 					      MHD_RESPMEM_PERSISTENT);
-  d = MHD_start_daemon (MHD_USE_SELECT_INTERNALLY | MHD_USE_SSL
+  d = MHD_start_daemon (MHD_USE_SELECT_INTERNALLY | MHD_USE_TLS
 #ifdef EPOLL_SUPPORT
 			| MHD_USE_EPOLL | MHD_USE_EPOLL_TURBO
 #endif
