@@ -86,20 +86,25 @@ MHD_state_to_string (enum MHD_CONNECTION_STATE state)
 #endif
 #endif
 
+
 #ifdef HAVE_MESSAGES
 /**
  * fprintf-like helper function for logging debug
  * messages.
  */
 void
-MHD_DLOG (const struct MHD_Daemon *daemon, const char *format, ...)
+MHD_DLOG (const struct MHD_Daemon *daemon,
+          const char *format,
+          ...)
 {
   va_list va;
 
   if (0 == (daemon->options & MHD_USE_DEBUG))
     return;
   va_start (va, format);
-  daemon->custom_error_log (daemon->custom_error_log_cls, format, va);
+  daemon->custom_error_log (daemon->custom_error_log_cls,
+                            format,
+                            va);
   va_end (va);
 }
 #endif
@@ -141,7 +146,9 @@ MHD_http_unescape (char *val)
       switch (*rpos)
 	{
 	case '%':
-          if (2 == MHD_strx_to_uint32_n_ (rpos + 1, 2, &num))
+          if (2 == MHD_strx_to_uint32_n_ (rpos + 1,
+                                          2,
+                                          &num))
 	    {
 	      *wpos = (char)((unsigned char) num);
 	      wpos++;
