@@ -35,7 +35,7 @@
 #ifdef _MHD_inline
 #undef _MHD_inline
 #endif /* _MHD_inline */
-/* Do not force inlining and do not use macro functions, use normal static 
+/* Do not force inlining and do not use macro functions, use normal static
    functions instead.
    This may give more flexibility for size optimizations. */
 #define _MHD_inline static
@@ -52,28 +52,33 @@
 #ifdef INLINE_FUNC
 /**
  * Check whether character is lower case letter in US-ASCII
+ *
  * @param c character to check
  * @return non-zero if character is lower case letter, zero otherwise
  */
 _MHD_inline _MHD_bool
 isasciilower (char c)
 {
-  return c >= 'a' && c <= 'z';
+  return (c >= 'a') && (c <= 'z');
 }
 
+
 /**
  * Check whether character is upper case letter in US-ASCII
+ *
  * @param c character to check
  * @return non-zero if character is upper case letter, zero otherwise
  */
 _MHD_inline _MHD_bool
 isasciiupper (char c)
 {
-  return c >= 'A' && c <= 'Z';
+  return (c >= 'A') && (c <= 'Z');
 }
 
+
 /**
  * Check whether character is letter in US-ASCII
+ *
  * @param c character to check
  * @return non-zero if character is letter in US-ASCII, zero otherwise
  */
@@ -83,19 +88,23 @@ isasciialpha (char c)
   return isasciilower (c) || isasciiupper (c);
 }
 
+
 /**
  * Check whether character is decimal digit in US-ASCII
+ *
  * @param c character to check
  * @return non-zero if character is decimal digit, zero otherwise
  */
 _MHD_inline _MHD_bool
 isasciidigit (char c)
 {
-  return c >= '0' && c <= '9';
+  return (c >= '0') && (c <= '9');
 }
 
+
 /**
  * Check whether character is hexadecimal digit in US-ASCII
+ *
  * @param c character to check
  * @return non-zero if character is decimal digit, zero otherwise
  */
@@ -103,12 +112,14 @@ _MHD_inline _MHD_bool
 isasciixdigit (char c)
 {
   return isasciidigit (c) ||
-         (c >= 'A' && c <= 'F') ||
-         (c >= 'a' && c <= 'f');
+    ( (c >= 'A') && (c <= 'F') ) ||
+    ( (c >= 'a') && (c <= 'f') );
 }
 
+
 /**
  * Check whether character is decimal digit or letter in US-ASCII
+ *
  * @param c character to check
  * @return non-zero if character is decimal digit or letter, zero otherwise
  */
@@ -118,11 +129,13 @@ isasciialnum (char c)
   return isasciialpha (c) || isasciidigit (c);
 }
 
+
 /**
  * Convert US-ASCII character to lower case.
  * If character is upper case letter in US-ASCII than it's converted to lower
  * case analog. If character is NOT upper case letter than it's returned
  * unmodified.
+ *
  * @param c character to convert
  * @return converted to lower case character
  */
@@ -132,11 +145,13 @@ toasciilower (char c)
   return isasciiupper (c) ? (c - 'A' + 'a') : c;
 }
 
+
 /**
  * Convert US-ASCII character to upper case.
  * If character is lower case letter in US-ASCII than it's converted to upper
  * case analog. If character is NOT lower case letter than it's returned
  * unmodified.
+ *
  * @param c character to convert
  * @return converted to upper case character
  */
@@ -146,8 +161,10 @@ toasciiupper (char c)
   return isasciilower (c) ? (c - 'a' + 'A') : c;
 }
 
+
 /**
  * Convert US-ASCII decimal digit to its value.
+ *
  * @param c character to convert
  * @return value of hexadecimal digit or -1 if @ c is not hexadecimal digit
  */
@@ -160,8 +177,10 @@ todigitvalue (char c)
   return -1;
 }
 
+
 /**
  * Convert US-ASCII hexadecimal digit to its value.
+ *
  * @param c character to convert
  * @return value of hexadecimal digit or -1 if @ c is not hexadecimal digit
  */
@@ -170,49 +189,59 @@ toxdigitvalue (char c)
 {
   if (isasciidigit (c))
     return (unsigned char)(c - '0');
-  if (c >= 'A' && c <= 'F')
+  if ( (c >= 'A') && (c <= 'F') )
     return (unsigned char)(c - 'A' + 10);
-  if (c >= 'a' && c <= 'f')
+  if ( (c >= 'a') && (c <= 'f') )
     return (unsigned char)(c - 'a' + 10);
 
   return -1;
 }
 #else  /* !INLINE_FUNC */
 
+
 /**
  * Checks whether character is lower case letter in US-ASCII
+ *
  * @param c character to check
  * @return boolean true if character is lower case letter,
  *         boolean false otherwise
  */
 #define isasciilower(c) (((char)(c)) >= 'a' && ((char)(c)) <= 'z')
 
+
 /**
  * Checks whether character is upper case letter in US-ASCII
+ *
  * @param c character to check
  * @return boolean true if character is upper case letter,
  *         boolean false otherwise
  */
 #define isasciiupper(c) (((char)(c)) >= 'A' && ((char)(c)) <= 'Z')
 
+
 /**
  * Checks whether character is letter in US-ASCII
+ *
  * @param c character to check
  * @return boolean true if character is letter, boolean false
  *         otherwise
  */
 #define isasciialpha(c) (isasciilower(c) || isasciiupper(c))
 
+
 /**
  * Check whether character is decimal digit in US-ASCII
+ *
  * @param c character to check
  * @return boolean true if character is decimal digit, boolean false
  *         otherwise
  */
 #define isasciidigit(c) (((char)(c)) >= '0' && ((char)(c)) <= '9')
 
+
 /**
  * Check whether character is hexadecimal digit in US-ASCII
+ *
  * @param c character to check
  * @return boolean true if character is hexadecimal digit,
  *         boolean false otherwise
@@ -221,41 +250,50 @@ toxdigitvalue (char c)
                           (((char)(c)) >= 'A' && ((char)(c)) <= 'F') || \
                           (((char)(c)) >= 'a' && ((char)(c)) <= 'f') )
 
+
 /**
  * Check whether character is decimal digit or letter in US-ASCII
+ *
  * @param c character to check
  * @return boolean true if character is decimal digit or letter,
  *         boolean false otherwise
  */
 #define isasciialnum(c) (isasciialpha(c) || isasciidigit(c))
 
+
 /**
  * Convert US-ASCII character to lower case.
  * If character is upper case letter in US-ASCII than it's converted to lower
  * case analog. If character is NOT upper case letter than it's returned
  * unmodified.
+ *
  * @param c character to convert
  * @return converted to lower case character
  */
 #define toasciilower(c) ((isasciiupper(c)) ? (((char)(c)) - 'A' + 'a') : ((char)(c)))
 
+
 /**
  * Convert US-ASCII character to upper case.
  * If character is lower case letter in US-ASCII than it's converted to upper
  * case analog. If character is NOT lower case letter than it's returned
  * unmodified.
+ *
  * @param c character to convert
  * @return converted to upper case character
  */
 #define toasciiupper(c) ((isasciilower(c)) ? (((char)(c)) - 'a' + 'A') : ((char)(c)))
 
+
 /**
  * Convert US-ASCII decimal digit to its value.
+ *
  * @param c character to convert
  * @return value of hexadecimal digit or -1 if @ c is not hexadecimal digit
  */
 #define todigitvalue(c) (isasciidigit(c) ? (int)(((char)(c)) - '0') : (int)(-1))
 
+
 /**
  * Convert US-ASCII hexadecimal digit to its value.
  * @param c character to convert
@@ -268,21 +306,25 @@ toxdigitvalue (char c)
                                (int)(((unsigned char)(c)) - 'a' + 10) : (int)(-1) )))
 #endif /* !INLINE_FUNC */
 
+
 #ifndef MHD_FAVOR_SMALL_CODE
 /**
  * Check two string for equality, ignoring case of US-ASCII letters.
+ *
  * @param str1 first string to compare
  * @param str2 second string to compare
  * @return non-zero if two strings are equal, zero otherwise.
  */
 int
-MHD_str_equal_caseless_ (const char * str1, const char * str2)
+MHD_str_equal_caseless_ (const char * str1,
+                         const char * str2)
 {
   while (0 != (*str1))
     {
       const char c1 = *str1;
       const char c2 = *str2;
-      if (c1 != c2 && toasciilower (c1) != toasciilower (c2))
+      if ( (c1 != c2) &&
+           (toasciilower (c1) != toasciilower (c2)) )
         return 0;
       str1++;
       str2++;
@@ -297,22 +339,27 @@ MHD_str_equal_caseless_ (const char * str1, const char * str2)
  * checking not more than @a maxlen characters.
  * Compares up to first terminating null character, but not more than
  * first @a maxlen characters.
+ *
  * @param str1 first string to compare
  * @param str2 second string to compare
  * @param maxlen maximum number of characters to compare
  * @return non-zero if two strings are equal, zero otherwise.
  */
 int
-MHD_str_equal_caseless_n_ (const char * const str1, const char * const str2, size_t maxlen)
+MHD_str_equal_caseless_n_ (const char * const str1,
+                           const char * const str2,
+                           size_t maxlen)
 {
   size_t i;
+
   for (i = 0; i < maxlen; ++i)
     {
       const char c1 = str1[i];
       const char c2 = str2[i];
       if (0 == c2)
         return 0 == c1;
-      if (c1 != c2 && toasciilower (c1) != toasciilower (c2))
+      if ( (c1 != c2) &&
+           (toasciilower (c1) != toasciilower (c2)) )
         return 0;
     }
   return !0;
@@ -324,17 +371,20 @@ MHD_str_equal_caseless_n_ (const char * const str1, const char * const str2, siz
 /**
  * Convert decimal US-ASCII digits in string to number in uint64_t.
  * Conversion stopped at first non-digit character.
+ *
  * @param str string to convert
- * @param out_val pointer to uint64_t to store result of conversion
+ * @param[out] out_val pointer to uint64_t to store result of conversion
  * @return non-zero number of characters processed on succeed,
  *         zero if no digit is found, resulting value is larger
  *         then possible to store in uint64_t or @a out_val is NULL
  */
-size_t 
-MHD_str_to_uint64_ (const char * str, uint64_t * out_val)
+size_t
+MHD_str_to_uint64_ (const char *str,
+                    uint64_t *out_val)
 {
   const char * const start = str;
   uint64_t res;
+
   if (!str || !out_val || !isasciidigit(str[0]))
     return 0;
 
@@ -343,7 +393,8 @@ MHD_str_to_uint64_ (const char * str, uint64_t * out_val)
     {
       const int digit = (unsigned char)(*str) - '0';
       if ( (res > (UINT64_MAX / 10)) ||
-           (res == (UINT64_MAX / 10) && (uint64_t)digit > (UINT64_MAX % 10)) )
+           ( (res == (UINT64_MAX / 10)) &&
+             ((uint64_t)digit > (UINT64_MAX % 10)) ) )
         return 0;
 
       res *= 10;
@@ -359,20 +410,24 @@ MHD_str_to_uint64_ (const char * str, uint64_t * out_val)
 /**
  * Convert not more then @a maxlen decimal US-ASCII digits in string to
  * number in uint64_t.
- * Conversion stopped at first non-digit character or after @a maxlen 
+ * Conversion stopped at first non-digit character or after @a maxlen
  * digits.
+ *
  * @param str string to convert
  * @param maxlen maximum number of characters to process
- * @param out_val pointer to uint64_t to store result of conversion
+ * @param[out] out_val pointer to uint64_t to store result of conversion
  * @return non-zero number of characters processed on succeed,
  *         zero if no digit is found, resulting value is larger
  *         then possible to store in uint64_t or @a out_val is NULL
  */
 size_t
-MHD_str_to_uint64_n_ (const char * str, size_t maxlen, uint64_t * out_val)
+MHD_str_to_uint64_n_ (const char * str,
+                      size_t maxlen,
+                      uint64_t *out_val)
 {
   uint64_t res;
   size_t i;
+
   if (!str || !maxlen || !out_val || !isasciidigit (str[0]))
     return 0;
 
@@ -381,14 +436,17 @@ MHD_str_to_uint64_n_ (const char * str, size_t maxlen, uint64_t * out_val)
   do
     {
       const int digit = (unsigned char)str[i] - '0';
+
       if ( (res > (UINT64_MAX / 10)) ||
-           (res == (UINT64_MAX / 10) && (uint64_t)digit > (UINT64_MAX % 10)) )
+           ( (res == (UINT64_MAX / 10)) &&
+             ((uint64_t)digit > (UINT64_MAX % 10)) ) )
         return 0;
 
       res *= 10;
       res += digit;
-      i++;      
-    } while(i < maxlen && isasciidigit(str[i]));
+      i++;
+    } while ( (i < maxlen) &&
+              isasciidigit (str[i]) );
 
   *out_val= res;
   return i;
@@ -398,18 +456,21 @@ MHD_str_to_uint64_n_ (const char * str, size_t maxlen, uint64_t * out_val)
 /**
  * Convert hexadecimal US-ASCII digits in string to number in size_t.
  * Conversion stopped at first non-digit character.
+ *
  * @param str string to convert
- * @param out_val pointer to size_t to store result of conversion
- * @return non-zero number of characters processed on succeed, 
+ * @param[out] out_val pointer to size_t to store result of conversion
+ * @return non-zero number of characters processed on succeed,
  *         zero if no digit is found, resulting value is larger
  *         then possible to store in size_t or @a out_val is NULL
  */
 size_t
-MHD_strx_to_sizet_ (const char * str, size_t * out_val)
+MHD_strx_to_sizet_ (const char *str,
+                    size_t *out_val)
 {
   const char * const start = str;
   size_t res;
   int digit;
+
   if (!str || !out_val)
     return 0;
 
@@ -418,7 +479,8 @@ MHD_strx_to_sizet_ (const char * str, size_t * out_val)
   while (digit >= 0)
     {
       if ( (res < (SIZE_MAX / 16)) ||
-           (res == (SIZE_MAX / 16) && (size_t)digit <= (SIZE_MAX % 16)) )
+           ( (res == (SIZE_MAX / 16)) &&
+             ((size_t)digit <= (SIZE_MAX % 16)) ) )
         {
           res *= 16;
           res += digit;
@@ -438,30 +500,35 @@ MHD_strx_to_sizet_ (const char * str, size_t * out_val)
 /**
  * Convert not more then @a maxlen hexadecimal US-ASCII digits in string
  * to number in size_t.
- * Conversion stopped at first non-digit character or after @a maxlen 
+ * Conversion stopped at first non-digit character or after @a maxlen
  * digits.
+ *
  * @param str string to convert
  * @param maxlen maximum number of characters to process
- * @param out_val pointer to size_t to store result of conversion
+ * @param[out] out_val pointer to size_t to store result of conversion
  * @return non-zero number of characters processed on succeed,
  *         zero if no digit is found, resulting value is larger
  *         then possible to store in size_t or @a out_val is NULL
  */
 size_t
-MHD_strx_to_sizet_n_ (const char * str, size_t maxlen, size_t * out_val)
+MHD_strx_to_sizet_n_ (const char * str,
+                      size_t maxlen,
+                      size_t *out_val)
 {
   size_t i;
   size_t res;
   int digit;
   if (!str || !out_val)
     return 0;
-  
+
   res = 0;
   i = 0;
-  while (i < maxlen && (digit = toxdigitvalue (str[i])) >= 0)
+  while ( (i < maxlen) &&
+          ((digit = toxdigitvalue (str[i])) >= 0) )
     {
       if ( (res > (SIZE_MAX / 16)) ||
-           (res == (SIZE_MAX / 16) && (size_t)digit > (SIZE_MAX % 16)) )
+           ( (res == (SIZE_MAX / 16)) &&
+             ((size_t)digit > (SIZE_MAX % 16)) ) )
         return 0;
 
       res *= 16;
@@ -478,18 +545,21 @@ MHD_strx_to_sizet_n_ (const char * str, size_t maxlen, size_t * out_val)
 /**
  * Convert hexadecimal US-ASCII digits in string to number in uint32_t.
  * Conversion stopped at first non-digit character.
+ *
  * @param str string to convert
- * @param out_val pointer to uint32_t to store result of conversion
- * @return non-zero number of characters processed on succeed, 
+ * @param[out] out_val pointer to uint32_t to store result of conversion
+ * @return non-zero number of characters processed on succeed,
  *         zero if no digit is found, resulting value is larger
  *         then possible to store in uint32_t or @a out_val is NULL
  */
 size_t
-MHD_strx_to_uint32_ (const char * str, uint32_t * out_val)
+MHD_strx_to_uint32_ (const char * str,
+                     uint32_t *out_val)
 {
   const char * const start = str;
   uint32_t res;
   int digit;
+
   if (!str || !out_val)
     return 0;
 
@@ -518,24 +588,27 @@ MHD_strx_to_uint32_ (const char * str, uint32_t * out_val)
 /**
  * Convert not more then @a maxlen hexadecimal US-ASCII digits in string
  * to number in uint32_t.
- * Conversion stopped at first non-digit character or after @a maxlen 
+ * Conversion stopped at first non-digit character or after @a maxlen
  * digits.
+ *
  * @param str string to convert
  * @param maxlen maximum number of characters to process
- * @param out_val pointer to uint32_t to store result of conversion
+ * @param[out] out_val pointer to uint32_t to store result of conversion
  * @return non-zero number of characters processed on succeed,
  *         zero if no digit is found, resulting value is larger
  *         then possible to store in uint32_t or @a out_val is NULL
  */
 size_t
-MHD_strx_to_uint32_n_ (const char * str, size_t maxlen, uint32_t * out_val)
+MHD_strx_to_uint32_n_ (const char *str,
+                       size_t maxlen,
+                       uint32_t *out_val)
 {
   size_t i;
   uint32_t res;
   int digit;
   if (!str || !out_val)
     return 0;
-  
+
   res = 0;
   i = 0;
   while (i < maxlen && (digit = toxdigitvalue (str[i])) >= 0)
@@ -558,14 +631,16 @@ MHD_strx_to_uint32_n_ (const char * str, size_t maxlen, uint32_t * out_val)
 /**
  * Convert hexadecimal US-ASCII digits in string to number in uint64_t.
  * Conversion stopped at first non-digit character.
+ *
  * @param str string to convert
- * @param out_val pointer to uint64_t to store result of conversion
- * @return non-zero number of characters processed on succeed, 
+ * @param[out] out_val pointer to uint64_t to store result of conversion
+ * @return non-zero number of characters processed on succeed,
  *         zero if no digit is found, resulting value is larger
  *         then possible to store in uint64_t or @a out_val is NULL
  */
 size_t
-MHD_strx_to_uint64_ (const char * str, uint64_t * out_val)
+MHD_strx_to_uint64_ (const char *str,
+                     uint64_t *out_val)
 {
   const char * const start = str;
   uint64_t res;
@@ -598,24 +673,27 @@ MHD_strx_to_uint64_ (const char * str, uint64_t * out_val)
 /**
  * Convert not more then @a maxlen hexadecimal US-ASCII digits in string
  * to number in uint64_t.
- * Conversion stopped at first non-digit character or after @a maxlen 
+ * Conversion stopped at first non-digit character or after @a maxlen
  * digits.
+ *
  * @param str string to convert
  * @param maxlen maximum number of characters to process
- * @param out_val pointer to uint64_t to store result of conversion
+ * @param[out] out_val pointer to uint64_t to store result of conversion
  * @return non-zero number of characters processed on succeed,
  *         zero if no digit is found, resulting value is larger
  *         then possible to store in uint64_t or @a out_val is NULL
  */
 size_t
-MHD_strx_to_uint64_n_ (const char * str, size_t maxlen, uint64_t * out_val)
+MHD_strx_to_uint64_n_ (const char * str,
+                       size_t maxlen,
+                       uint64_t *out_val)
 {
   size_t i;
   uint64_t res;
   int digit;
   if (!str || !out_val)
     return 0;
-  
+
   res = 0;
   i = 0;
   while (i < maxlen && (digit = toxdigitvalue (str[i])) >= 0)
@@ -639,9 +717,10 @@ MHD_strx_to_uint64_n_ (const char * str, size_t maxlen, uint64_t * out_val)
 /**
  * Generic function for converting not more then @a maxlen
  * hexadecimal or decimal US-ASCII digits in string to number.
- * Conversion stopped at first non-digit character or after @a maxlen 
+ * Conversion stopped at first non-digit character or after @a maxlen
  * digits.
  * To be used only within macro.
+ *
  * @param str the string to convert
  * @param maxlen the maximum number of characters to process
  * @param out_val the pointer to variable to store result of conversion
@@ -653,8 +732,12 @@ MHD_strx_to_uint64_n_ (const char * str, size_t maxlen, uint64_t * out_val)
  *         then @max_val, @val_size is not 16/32 or @a out_val is NULL
  */
 size_t
-MHD_str_to_uvalue_n_ (const char * str, size_t maxlen,
-                      void * out_val, size_t val_size, uint64_t max_val, int base)
+MHD_str_to_uvalue_n_ (const char *str,
+                      size_t maxlen,
+                      void * out_val,
+                      size_t val_size,
+                      uint64_t max_val,
+                      int base)
 {
   size_t i;
   uint64_t res;
@@ -664,6 +747,7 @@ MHD_str_to_uvalue_n_ (const char * str, size_t maxlen,
   /* 'digit->value' must be function, not macro */
   int (*const dfunc)(char) = (base == 16) ?
                               toxdigitvalue : todigitvalue;
+
   if ( !str || !out_val ||
        (base != 16 && base != 10) )
     return 0;
