@@ -27,11 +27,11 @@
 
 #include "platform.h"
 #include "microhttpd.h"
-#include "internal.h"
 #include "tls_test_common.h"
 #include <gcrypt.h>
 #include "mhd_sockets.h" /* only macros used */
 
+
 #ifdef _WIN32
 #ifndef WIN32_LEAN_AND_MEAN
 #define WIN32_LEAN_AND_MEAN 1
@@ -70,7 +70,7 @@ test_tls_session_time_out (gnutls_session_t session)
   if (ret < 0)
     {
       fprintf (stderr, "Error: %s\n", MHD_E_FAILED_TO_CONNECT);
-      MHD_socket_close_ (sd);
+      MHD_socket_close_chk_ (sd);
       return -1;
     }
 
@@ -78,7 +78,7 @@ test_tls_session_time_out (gnutls_session_t session)
   if (ret < 0)
     {
       fprintf (stderr, "Handshake failed\n");
-      MHD_socket_close_ (sd);
+      MHD_socket_close_chk_ (sd);
       return -1;
     }
 
@@ -89,11 +89,11 @@ test_tls_session_time_out (gnutls_session_t session)
   if (send (sd, "", 1, 0) == 0)
     {
       fprintf (stderr, "Connection failed to time-out\n");
-      MHD_socket_close_ (sd);
+      MHD_socket_close_chk_ (sd);
       return -1;
     }
 
-  MHD_socket_close_ (sd);
+  MHD_socket_close_chk_ (sd);
   return 0;
 }
 
@@ -116,7 +116,7 @@ main (int argc, char *const *argv)
   gnutls_global_init ();
   gnutls_global_set_log_level (11);
 
-  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_SSL |
+  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_TLS |
                         MHD_USE_DEBUG, DEAMON_TEST_PORT,
                         NULL, NULL, &http_dummy_ahc, NULL,
                         MHD_OPTION_CONNECTION_TIMEOUT, TIME_OUT,
